==> med-fichier_2.3.1.orig.tar.gz: med-2.3.1/src/ci/MEDnumLire.c <==
/*************************************************************************
* COPYRIGHT (C) 1999 - 2005  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

#include <med.h>
#include <med_config.h>
#include <med_outils.h>

#include <stdlib.h>
#include <string.h>

med_err 
MEDnumLire(med_idt fid,char *maa, med_int *num, med_int n, 
	   med_entite_maillage type_ent,med_geometrie_element type_geo)
{
  med_idt root;
  med_idt maaid = 0;
  med_idt geoid = 0;
  med_idt entid = 0;
  med_err ret = -1;
  char chemin[MED_TAILLE_MAA+MED_TAILLE_NOM+1];
  char nom_ent[MED_TAILLE_NOM_ENTITE+1];
  char nom_geo[MED_TAILLE_NOM_ENTITE+1];

  /*
   * On inhibe le gestionnaire d'erreur HDF 5
   */
  _MEDmodeErreurVerrouiller(); 

  /*
   * Si le maillage n'existe pas => erreur
   */
  strcpy(chemin,MED_MAA);
  strcat(chemin,maa);
  if ((maaid = _MEDdatagroupOuvrir(fid,chemin)) < 0) {
    MESSAGE("Impossible d'acceder au maillage");
    SSCRUTE(chemin);
    goto ERREUR;
  }

  /*
   * On met a jour le nom du "Data Group" representant
   * le type des entites
   */
  if (_MEDnomEntite(nom_ent,type_ent) < 0) {
    MESSAGE("L'entit demande n'est pas une entit <med_entite_maillage> : ");
    SSCRUTE(nom_ent); 
    ISCRUTE(type_ent);
    goto ERREUR;
  }
  
  /*
   * Si le "Data Group" des entites n'existe pas => erreur
   */
  if ((entid = _MEDdatagroupOuvrir(maaid,nom_ent)) < 0) { 
    MESSAGE("Impossible d'accder au groupe des entits : ");
    SSCRUTE(nom_ent); 
    ISCRUTE(type_ent);
    goto ERREUR;
  }
  
  /*
   * Pour les mailles, les faces et le aretes :
   * - Si le "Data Group" du type geometrique n'existe pas => erreur
   */
  if ((type_ent==MED_MAILLE)||(type_ent==MED_FACE)||(type_ent==MED_ARETE))
    {
      if (_MEDnomGeometrie(nom_geo,type_geo) < 0) {
	MESSAGE("L'entit demande n'est pas un lment <med_geometrie_element> : ");
	SSCRUTE(nom_geo); 
	ISCRUTE(type_geo);
	goto ERREUR;
      }
      if ((geoid = _MEDdatagroupOuvrir(entid,nom_geo)) < 0) {
	MESSAGE("Impossible d'accder au groupe des lments gomtriques : ");
	SSCRUTE(nom_geo); 
	ISCRUTE(type_geo);
	goto ERREUR;
      }
    }
   else 
     geoid = -1;

   /*
    * lecture du Data Set "NUM" :
    * - En cas d'erreur, pas de message car la presence des 
    *   numeros est optionnelle dans un fichier MED
    */
   if (geoid == -1)
     root = entid;
   else
     root = geoid;
#if defined(HAVE_F77INT64)
   if (_MEDdatasetNumLire(root,MED_NOM_NUM,MED_INT64,
			  MED_NO_INTERLACE,1,MED_ALL,
			  MED_NOPF,MED_NO_PFLMOD,0,MED_NOPG,
			  (unsigned char*) num) < 0)
     goto ERREUR;
#else
   if (_MEDdatasetNumLire(root,MED_NOM_NUM,MED_INT32,
			  MED_NO_INTERLACE,1,MED_ALL,
			  MED_NOPF,MED_NO_PFLMOD,0,MED_NOPG,
			  (unsigned char*) num) < 0)
     goto ERREUR;
#endif
   
   /*
    * Tout s'est bien pass si on est parvenu jusqu'ici
    */
   ret = 0;

   /*
    * On ferme tout y compris en cas d'erreur
    */
 ERREUR:
   if (geoid > 0)
     if (_MEDdatagroupFermer(geoid) < 0)
       return -1;
   if (entid > 0)
     if (_MEDdatagroupFermer(entid) < 0)
       return -1;
   if (maaid > 0)
     if (_MEDdatagroupFermer(maaid) < 0)
       return -1;

   /* Code retour : 
    *   - ret == 0 en cas de succs
    *   - ret == -1 en cas d'chec 
    */
   return (ret); 
}

==> med-fichier_2.3.5.orig.tar.gz: med-2.3.5/src/ci/MEDnumLire.c <==
/*************************************************************************
* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

#include <med.h>
#include <med_config.h>
#include <med_outils.h>

#include <stdlib.h>
#include <string.h>

med_err 
MEDnumLire(med_idt fid,char *maa, med_int *num, med_int n, 
	   med_entite_maillage type_ent,med_geometrie_element type_geo)
{
  med_idt root;
  med_idt maaid = 0;
  med_idt geoid = 0;
  med_idt entid = 0;
  med_err ret = -1;
  char chemin[MED_TAILLE_MAA+MED_TAILLE_NOM+1];
  char nom_ent[MED_TAILLE_NOM_ENTITE+1];
  char nom_geo[MED_TAILLE_NOM_ENTITE+1];
  med_entite_maillage _type_ent=type_ent;

  if ( type_ent == MED_NOEUD_MAILLE ) _type_ent=MED_NOEUD ;

  /*
   * On inhibe le gestionnaire d'erreur HDF 5
   */
  _MEDmodeErreurVerrouiller(); 

  /*
   * Si le maillage n'existe pas => erreur
   */
  strcpy(chemin,MED_MAA);
  strcat(chemin,maa);
  if ((maaid = _MEDdatagroupOuvrir(fid,chemin)) < 0) {
    MESSAGE("Impossible d'acceder au maillage");
    SSCRUTE(chemin);
    goto ERREUR;
  }

  /*
   * On met a jour le nom du "Data Group" representant
   * le type des entites
   */
  if (_MEDnomEntite(nom_ent,_type_ent) < 0) {
    MESSAGE("L'entit demande n'est pas une entit <med_entite_maillage> : ");
    SSCRUTE(nom_ent); 
    ISCRUTE(_type_ent);
    goto ERREUR;
  }
  
  /*
   * Si le "Data Group" des entites n'existe pas => erreur
   */
  if ((entid = _MEDdatagroupOuvrir(maaid,nom_ent)) < 0) { 
    MESSAGE("Impossible d'accder au groupe des entits : ");
    SSCRUTE(nom_ent); 
    ISCRUTE(_type_ent);
    goto ERREUR;
  }
  
  /*
   * Pour les mailles, les faces et le aretes :
   * - Si le "Data Group" du type geometrique n'existe pas => erreur
   */
  if ((_type_ent==MED_MAILLE)||(_type_ent==MED_FACE)||(_type_ent==MED_ARETE))
    {
      if (_MEDnomGeometrie(nom_geo,type_geo) < 0) {
	MESSAGE("L'entit demande n'est pas un lment <med_geometrie_element> : ");
	SSCRUTE(nom_geo); 
	ISCRUTE(type_geo);
	goto ERREUR;
      }
      if ((geoid = _MEDdatagroupOuvrir(entid,nom_geo)) < 0) {
	MESSAGE("Impossible d'accder au groupe des lments gomtriques : ");
	SSCRUTE(nom_geo); 
	ISCRUTE(type_geo);
	goto ERREUR;
      }
    }
   else 
     geoid = -1;

   /*
    * lecture du Data Set "NUM" :
    * - En cas d'erreur, pas de message car la presence des 
    *   numeros est optionnelle dans un fichier MED
    */
   if (geoid == -1)
     root = entid;
   else
     root = geoid;
#if defined(HAVE_F77INT64)
   if (_MEDdatasetNumLire(root,MED_NOM_NUM,MED_INT64,
			  MED_NO_INTERLACE,1,MED_ALL,
			  MED_NOPF,MED_NO_PFLMOD,MED_PFL_NON_COMPACT,0,MED_NOPG,0,
			  (unsigned char*) num) < 0)
     goto ERREUR;
#else
   if (_MEDdatasetNumLire(root,MED_NOM_NUM,MED_INT32,
			  MED_NO_INTERLACE,1,MED_ALL,
			  MED_NOPF,MED_NO_PFLMOD,MED_PFL_NON_COMPACT,0,MED_NOPG,0,
			  (unsigned char*) num) < 0)
     goto ERREUR;
#endif
   
   /*
    * Tout s'est bien pass si on est parvenu jusqu'ici
    */
   ret = 0;

   /*
    * On ferme tout y compris en cas d'erreur
    */
 ERREUR:
   if (geoid > 0)
     if (_MEDdatagroupFermer(geoid) < 0)
       return -1;
   if (entid > 0)
     if (_MEDdatagroupFermer(entid) < 0)
       return -1;
   if (maaid > 0)
     if (_MEDdatagroupFermer(maaid) < 0)
       return -1;

   /* Code retour : 
    *   - ret == 0 en cas de succs
    *   - ret == -1 en cas d'chec 
    */
   return (ret); 
}
